@@ -1,4 +1,6 @@
+/* Copyright (c) 1994 Sanjay Ghemawat */
 #include "options.h"
+#include "misc.h"
 
 OptionMap::~OptionMap() {
     for (OptionMap_Bindings b = rep; b.ok(); b.next()) {
@@ -9,20 +11,15 @@ OptionMap::~OptionMap() {
 }
 
 void OptionMap::store(char const* key, char const* value) {
-    char* copy = new char[strlen(value)+1];
-    strcpy(copy, value);
-
     char const* old_value;
     if (rep->fetch(key, old_value)) {
 	// Replace old value with new
-	rep->store(key, copy);
+	rep->store(key, copy_string(value));
 	delete [] ((char*) old_value);
     }
     else {
 	// Insert new value
-	char* copy_key = new char[strlen(key)+1];
-	strcpy(copy_key, key);
-	rep->store(copy_key, copy);
+	rep->store(copy_string(key), copy_string(value));
     }
 }
 
