@@ -5,10 +5,17 @@
 #include <unistd.h>
 
 #include "config.h"
+#include "misc.h"
 #include "uid.h"
 
 #ifndef HAVE_GETHOSTNAME_PROTO
+
+#ifdef linux
+extern "C" int gethostname(char*, unsigned int);
+#else /* !linux */
 extern "C" int gethostname(char*, int);
+#endif /* linux */
+
 #endif
 
 #ifdef HAVE_GETHOSTID
@@ -51,9 +58,7 @@ char const* uid_new() {
     sprintf(buffer, "%s_%x_%x_%x", hostname, hostid, pid, counter);
     counter++;
 
-    char* id = new char[strlen(buffer)+1];
-    strcpy(id, buffer);
-    return id;
+    return copy_string(buffer);
 }
 
 implementOpenHashSet(UidSet,char const*,hash_string,equal_uid)
