@@ -15,6 +15,7 @@
 #include "calfile.h"
 #include "commands.h"
 #include "collect.h"
+#include "item_tcl.h"
 #include "misc_tcl.h"
 
 static int monday_first();
@@ -79,9 +80,9 @@ int Cmd_MonthDays(ClientData, Tcl_Interp* tcl, int argc, char* argv[]) {
  *		also has the tag "Day".
  *
  * effects	Configures items so that they have tag "interest" iff
- *		the corresponding date has interesting items.  Any
- *		items which initially had interest, but no longer,
- *		are tagged with "oldinterest".
+ *		the corresponding date has interesting items.  Also
+ *		configure the items to have tag "holiday" iff the
+ *		corresponding date has an item marked as a holiday item.
  */
 int Cmd_InterestTags(ClientData, Tcl_Interp* tcl, int argc, char* argv[]) {
     if (argc != 3) {
@@ -103,46 +104,59 @@ int Cmd_InterestTags(ClientData, Tcl_Interp* tcl, int argc, char* argv[]) {
 	blanks = (blanks + 6)%7;
     }
 
-    int interest[43];
+    int interest[43], holiday[43];
     for (int i = 1; i <= 42; i++) {
 	interest[i] = 0;
+	holiday[i] = 0;
     }
 
+    Date today = Date::Today();
     Occurrences list;
     collect_occurrences(list, first, last, 0);
     for (i = 0; i < list.size(); i++) {
-	interest[(list[i].date - first) + blanks + 1] = 1;
+	int index = (list[i].date - first) + blanks + 1;
+
+	char const* hilite = list[i].item->value()->Hilite();
+
+	if (strcmp(hilite, "never") == 0) {
+	    continue;
+	}
+
+	if (strcmp(hilite, "holiday") == 0) {
+	    holiday[index] = 1;
+	    continue;
+	}
+
+	if (strcmp(hilite, "expire") == 0) {
+	    if (list[i].date >= today) {
+		interest[index] = 1;
+	    }
+	    continue;
+	}
+
+	interest[index] = 1;
     }
 
-    /* Rename interest to oldinterest */
     char* canvas = argv[1];
-    if (Tcl_VarEval(tcl, canvas, " addtag oldinterest withtag interest", NULL)
-	!= TCL_OK) {
-	return TCL_ERROR;
-    }
-    if (Tcl_VarEval(tcl, canvas, " dtag interest interest", NULL) != TCL_OK) {
-	return TCL_ERROR;
-    }
 
     /* Add interest to everything that we are still interested in */
     for (i = 1; i <= 42; i++) {
+	char str[100];
+	sprintf(str, "=%d", i);
+
 	if (interest[i]) {
-	    char str[100];
-	    sprintf(str, "=%d", i);
-	    if (Tcl_VarEval(tcl,
-			    canvas,
-			    " addtag interest withtag ",
-			    str,
+	    if (Tcl_VarEval(tcl, canvas, " addtag interest withtag ", str,
 			    NULL) != TCL_OK) {
 		return TCL_ERROR;
 	    }
 	}
-    }
 
-    /* Remove oldinterest for items with interest */
-    if (Tcl_VarEval(tcl, canvas, " dtag interest oldinterest", NULL)
-	!= TCL_OK) {
-	return TCL_ERROR;
+	if (holiday[i]) {
+	    if (Tcl_VarEval(tcl, canvas, " addtag holiday withtag ", str,
+			    NULL) != TCL_OK) {
+		return TCL_ERROR;
+	    }
+	}
     }
 
     TCL_Return(tcl, "");
