@@ -18,8 +18,9 @@ class DayView {} {
     global dv_state
 
     lappend dv_state(views) $self
-    set dv_state($self,remind) -1
+    set dv_state($self,remind)    -1
     set dv_state($self,defremind) -1
+    set dv_state($self,hilite)    ""
 
     set name .$self
     set slot(window) $name
@@ -50,6 +51,7 @@ class DayView {} {
     pack append $name $name.status {bottom fillx}
 
     $self pack
+    $self geometry
 
     wm title $name Calendar
     wm iconname $name ical
@@ -74,6 +76,11 @@ class DayView {} {
 
     # Useful for reconfiguration
     trigger on include	[list $self included]
+
+    # To advance the view at midnight
+    trigger on midnight [list $self midnight]
+
+    run-hook dayview-startup $self
 }
 
 method DayView window {} {
@@ -93,13 +100,14 @@ method DayView cleanup {} {
     }
 
     if {[llength $dv_state(views)] == 0} {
+	run-hook ical-exit
 	destroy .
     } else {
 	focus_disinterest $slot(window)
 	focus_unrestrict $slot(window)
 
 	unset dv_state($self,remind)
-	unset dv_state($self,vertical)
+	unset dv_state($self,hilite)
 	unset dv_state($self,overflow)
 	unset dv_state($self,ampm)
 	unset dv_state($self,mondayfirst)
@@ -107,6 +115,7 @@ method DayView cleanup {} {
 
 	trigger remove change [list $self change]
 	trigger remove include [list $self included]
+	trigger remove midnight [list $self midnight]
 
 	class_kill $slot(apptlist)
 	class_kill $slot(notelist)
@@ -122,12 +131,20 @@ method DayView set_date {date} {
     $slot(notelist) set_date $date
 }
 
+# Called at midnight by a trigger.  Advance to today if appropriate.
+method DayView midnight {} {
+    # Only advance if at previous date
+    set today [date today]
+    if {$slot(date) == ($today-1)} {$self set_date $today}
+}
+
 method DayView focus {item itemwindow} {
     set slot(focus) $item
     set slot(focuswindow) $itemwindow
 
     global dv_state
     set dv_state($self,remind) [$item earlywarning]
+    set dv_state($self,hilite) [$item hilite]
 
     global dv_state
     foreach entry $dv_state(item_entries) {
@@ -148,6 +165,7 @@ method DayView unfocus {} {
 
     global dv_state
     set dv_state($self,remind) -1
+    set dv_state($self,hilite) ""
 
     global dv_state
     foreach entry $dv_state(item_entries) {
@@ -181,6 +199,10 @@ method DayView update_status {} {
     } else {
 	set disp [file tail [$item calendar]]
 
+	if {[$item hilite] == "holiday"} {
+	    set disp [format {%s Holiday} $disp]
+	}
+
 	set owner [$item owner]
 	if {$owner != ""} {
 	    set disp [format {%s [%s]} $disp $owner]
@@ -218,7 +240,7 @@ method DayView key {{str ""}} {
 
 method DayView save {} {
     trigger fire save
-    foreach file [calendar_filenames] {
+    foreach file [ical_filenames] {
 	if ![cal dirty $file] {continue}
 
 	if [cal stale $file] {
@@ -247,7 +269,7 @@ method DayView save {} {
 method DayView reread {} {
     trigger fire save
 
-    # Cannot use [calendar_filenames] because main calendar may change
+    # Cannot use [ical_filenames] because main calendar may change
     # in the middle of the iteration.
 
     set cleanup 0
@@ -290,6 +312,8 @@ method DayView reread_calendar {file} {
 
 method DayView exit {} {
     if ![$self save] return
+
+    run-hook ical-exit
     destroy .
 }
 
@@ -298,6 +322,8 @@ method DayView newview {} {
 }
 
 method DayView close {} {
+    run-hook dayview-close $self
+
     global dv_state
     if {[llength $dv_state(views)] <= 1} {
 	# Last view about to be closed - try and save.
@@ -411,6 +437,17 @@ method DayView insert {} {
     }
 }
 
+method DayView import {} {
+    if [catch {set sel [selection get]}] {return}
+
+    if ![cal readonly] {
+	set item [item_parse $sel $slot(date)]
+	cal add $item
+	trigger fire add $item
+	$self set_date [$item first]
+    }
+}
+
 method DayView makeunique {} {
     set item [$self mod_selection]
     if {$item != ""} {
@@ -607,6 +644,15 @@ method DayView remind {n} {
     }
 }
 
+method DayView hilite {mode} {
+    set item [$self mod_single_selection]
+    if {$item != ""} {
+	$item hilite $mode
+	cal changed $item
+	trigger fire change $item
+    }
+}
+
 method DayView print {} {
     if [catch {print_calendar $slot(window) $slot(date)} msg] {
 	error_notify $slot(window) $msg
@@ -634,19 +680,15 @@ method DayView list {n} {
 	set start [expr $slot(date)+1-[date monthday $slot(date)]]
 	set n [date monthsize $start]
     }
+    if {$n == "year"} {
+	set start [date make 1 1 [date year $slot(date)]]
+	set n [expr [date make 1 1 [expr [date year $slot(date)]+1]] - $start]
+    }
 
     set l [ItemListing]
     $l dayrange $start [expr $start+$n-1]
 }
 
-method DayView toggle_vertical {} {
-    global dv_state
-    if [cal readonly] {return}
-
-    cal option VerticalLayout $dv_state($self,vertical)
-    $self reconfig_all
-}
-
 method DayView toggle_overflow {} {
     global dv_state
     if [cal readonly] {return}
@@ -735,25 +777,23 @@ method DayView reconfig_all {} {
 
 method DayView reconfig {} {
     set name .$self
-    pack forget $name.menu $name.status $name.al $name.nl $name.de
-
     $slot(apptlist) reconfig
     $slot(notelist) reconfig
     $slot(dateeditor) reconfig
-
-    $self pack
+    $self geometry
 }
 
 method DayView pack {} {
     set name .$self
-    set alside right
-    if [cal option VerticalLayout] {set alside bottom}
-
     pack $name.menu	-side top -fill x
     pack $name.status	-side bottom -fill x
-    pack $name.al	-side $alside -expand 1 -fill both
+    pack $name.al	-side right -expand 1 -fill both
     pack $name.nl	-side bottom -expand 1 -fill both
     pack $name.de	-side top -fill x
+}
+
+method DayView geometry {} {
+    set name .$self
 
     # Geometry management
     set width [winfo pixels $name "[cal option ItemWidth]c"]
@@ -776,8 +816,6 @@ method DayView build_menu {} {
     frame $m -relief raised -bd 1
 
     set menu_list ""
-    set sep [winfo pixels . 0.2i]
-    set pad 0
 
     global dayview_menus
     foreach menu $dayview_menus {
@@ -787,10 +825,9 @@ method DayView build_menu {} {
 
 	# Create menu
 	lappend menu_list $m.$name
-	menubutton $m.$name -bd 1 -text $title -menu $m.$name.m
+	menubutton $m.$name -bd 1 -text $title -menu $m.$name.m -padx 2m
 	menu $m.$name.m -bd 1
-	pack append $m $m.$name [list left padx $pad]
-	set pad $sep
+	pack append $m $m.$name {left}
 
 	# Fill menu
 	foreach entry $menu {
@@ -879,10 +916,12 @@ set dayview_menus {
 	{ {Copy}		{^c}	{copy}		}
 	{ {Paste}		{^v}	{paste}		}
 	{ {Insert Selection}	{^y}	{insert}	}
+	{ {Import Selection}	{}	{import}	}
 	{ -						}
-	{ {Make Unique}		{}	{makeunique}	}
-	{ {Change Alarms}	{}	{alarms}	}
-	{ > {List Item}		{early}	{early remind remind}	}
+	{ {Make Unique}		{}	 {makeunique}	}
+	{ {Change Alarms}	{}	 {alarms}	}
+	{ > {List Item}		{early}	 {early remind remind}	}
+	{ > {Highlight}		{hilite} {hilitemenu}	}
 	{ -						}
 	{ > {Move Item To}   {move}   {fillinc all moveitem} }
     }
@@ -916,6 +955,7 @@ set dayview_menus {
 	{ {Thirty Days}		{}	{list 30}	}
 	{ {Week}		{}	{list week}	}
 	{ {Month}		{}	{list month}	}
+	{ {Year}		{}	{list year}	}
 	{ -						}
 	{ > {From Calendar} {items}  {fillinc all viewitems} }
     }
@@ -928,7 +968,6 @@ set dayview_menus {
 	{ x {Allow Text Overflow}  {overflow}	  {toggle_overflow}	}
 	{ x {Display Am/Pm}	   {ampm}	  {toggle_ampm}		}
 	{ x {Start Week on Monday} {mondayfirst}  {toggle_monday}	}
-	{ x {Vertical Layout}	   {vertical}	  {toggle_vertical}	}
 	{ -								}
 	{ {Default Alarms}	 {}		  {defalarms}		}
 	{ > {Default Listings}   {early}	  {early defremind defremind} }
@@ -945,6 +984,7 @@ set dv_state(item_entries) {
     { edit	{Move Item To}		}
     { edit	{Change Alarms}		}
     { edit	{List Item}		}
+    { edit	{Highlight}		}
     { rep	{Don't Repeat}		}
     { rep	{Daily}			}
     { rep	{Weekly}		}
@@ -1047,6 +1087,27 @@ method DayView early {cmd var menu} {
     }
 }
 
+# effects - Fill hilite menu
+method DayView hilitemenu {menu} {
+    # No need to re-execute the -postcommand
+    $menu configure -postcommand ""
+
+    set entries {
+	{ {Always}		{always}	}
+	{ {Until Occurrence}	{expire}	}
+	{ {Never}		{never}		}
+	{ {As Holiday}		{holiday}	}
+    }
+
+    foreach e $entries {
+	$menu add radiobutton\
+	    -label [lindex $e 0]\
+	    -variable dv_state($self,hilite)\
+	    -value [lindex $e 1]\
+	    -command [list $self hilite [lindex $e 1]]
+    }
+}
+
 # effects - Configure the customization menu
 method DayView config_custom {} {
     global dv_state
@@ -1060,7 +1121,6 @@ method DayView config_custom {} {
 	catch {$menu entryconfig $i -state $state}
     }
 
-    set dv_state($self,vertical)	[cal option VerticalLayout]
     set dv_state($self,overflow)	[cal option AllowOverflow]
     set dv_state($self,ampm)		[cal option AmPm]
     set dv_state($self,mondayfirst)	[cal option MondayFirst]
@@ -1077,4 +1137,10 @@ method DayView config_edit {} {
     } else {
 	$menu entryconfig {Paste} -state normal
     }
+
+    if [cal readonly] {
+	$menu entryconfig {Import Selection} -state disabled
+    } else {
+	$menu entryconfig {Import Selection} -state normal
+    }
 }
