@@ -16,7 +16,7 @@ proc do_io {interval} {
 proc io_checks {} {
     trigger fire save
 
-    # Cannot use [calendar_filenames] because main calendar may change
+    # Cannot use [ical_filenames] because main calendar may change
     # in the middle of the iteration.
 
     set cleanup 0
@@ -53,11 +53,11 @@ proc io_check {calendar} {
     }
 
     if {$stale && $dirty} {
-	set result [yes_or_no	""\
+	set reread [yes_or_no	""\
 				"Conflicting changes to $calendar"\
 				"Read from disk"\
 				"Overwrite"]
-	if {$result} {
+	if {$reread} {
 	    # Discard local changes
 	    trigger fire exclude $calendar
 	    if [catch {cal reread $calendar} result] {
@@ -70,6 +70,8 @@ proc io_check {calendar} {
 	if [catch {cal save $calendar} result] {
 	    error_notify "" "$calendar\n\n$result"
 	}
-	return $result
+	return $reread
     }
+
+    return 0
 }
