@@ -1,42 +1,6 @@
 # Copyright (c) 1993 by Sanjay Ghemawat
-###############################################################################
+##############################################################################
 # Various Support Routines
-#
-# Global Variables
-#
-#	month_name		Array of month names
-#	weekday_name		Array of weekday names
-#
-
-############################################################################
-# Configuration Section
-#
-#	author_mail	Email address for bug notifications
-#	mailer		Mail program
-#	version		Ical version information
-
-set author_mail		"sanjay@lcs.mit.edu"
-set ical_version	"1.7"
-
-if [catch {set mailer $env(ICAL_MAILER)}] {
-    puts stderr "ical: could not find mailer specification"
-    exit 1
-}
-
-if {[info tclversion] < 7.0} {
-    puts stderr "ical: Tcl version < 7.0 cannot be used with ical"
-    exit 1
-}
-
-if ![catch {set tk_version}] {
-    if {$tk_version < 3.3} {
-	puts stderr "ical: Tk version < 3.3 cannot be used with ical"
-	exit 1
-    }
-}
-
-set calfile [file dirname ~/junk]/.calendar
-catch {set calfile $env(CALENDAR)}
 
 proc support_init {} {
     global month_name
@@ -67,7 +31,7 @@ proc support_init {} {
     set weekday_name(7)	Saturday
 }
 
-proc calendar_filenames {} {
+proc ical_filenames {} {
     set list ""
     lappend list [cal main]
     cal forincludes x {
@@ -135,7 +99,7 @@ proc repeat_check {leader item date} {
 }
 
 # effects - Print usage message and exist
-proc usage {} {
+proc ical_usage {} {
     puts stderr {Usage: ical [options]
           -calendar <file>              ; Calendar file
           -list                         ; List imminent items
@@ -149,3 +113,60 @@ proc usage {} {
           -geometry <geometry>          ; Initial window geometry}
     exit 1
 }
+
+# effects - Parse some standard arguments
+proc ical_parse_args {} {
+    global argv ical
+    set mono 0
+
+    set oldargv $argv
+    set argv {}
+    while {[llength $oldargv] > 0} {
+	set arg [lindex $oldargv 0]
+	set oldargv [lrange $oldargv 1 end]
+
+	if {![string compare $arg "-calendar"] && ([llength $oldargv] >= 1)} {
+	    set ical(calendar) [lindex $oldargv 0]
+	    set oldargv [lrange $oldargv 1 end]
+	    continue
+	}
+
+	lappend argv $arg
+    }
+}
+
+# effects - Parse some standard Tk arguments
+proc ical_parse_tk_args {} {
+    global argv ical
+
+    set oldargv $argv
+    set argv {}
+    while {[llength $oldargv] > 0} {
+	set arg [lindex $oldargv 0]
+	set oldargv [lrange $oldargv 1 end]
+
+	if {![string compare $arg "-iconic"]} {
+	    set ical(iconic) 1
+	    continue
+	}
+
+	if {![string compare $arg "-mono"]} {
+	    tk colormodel . mono
+	    continue
+	}
+
+	if {![string compare $arg "-bg"] && ([llength $oldargv] >= 1)} {
+	    lappend ical(prefs) "option add *Background [lindex $oldargv 0]"
+	    set oldargv [lrange $oldargv 1 end]
+	    continue
+	}
+
+	if {![string compare $arg "-fg"] && ([llength $oldargv] >= 1)} {
+	    lappend ical(prefs) "option add *Foreground [lindex $oldargv 0]"
+	    set oldargv [lrange $oldargv 1 end]
+	    continue
+	}
+
+	lappend argv $arg
+    }
+}
